==> SimplyDualWielding-7.0.0%2B1.21.1-Fabric-sources.jar: eva/dualwielding/network/ConfigPacket.java <==
package eva.dualwielding.network;

import eva.dualwielding.DualWieldingServer;
import eva.dualwielding.config.SimplyDualWieldingConfig;
import eva.dualwielding.config.enums.BalanceMode;
import eva.dualwielding.config.enums.ConditionalBehavior;
import eva.dualwielding.config.enums.ItemCat;
import net.minecraft.class_2540;
import net.minecraft.class_8710;
import net.minecraft.class_9139;
import org.jetbrains.annotations.NotNull;

public record ConfigPacket(SimplyDualWieldingConfig heldInstance) implements class_8710 {
    public static final class_9154<ConfigPacket> ID = new class_9154<>(DualWieldingServer.CONFIG_PACKET_ID);
    public static final class_9139<class_2540, ConfigPacket> CODEC = class_8710.method_56484(ConfigPacket::write, ConfigPacket::new);

    private ConfigPacket(class_2540 buf) {
        this(buildFromBuf(buf));
    }

    private static SimplyDualWieldingConfig buildFromBuf(class_2540 buf) {
        boolean empty = buf.readBoolean();
        int p = buf.readByte();
        boolean[] allowWeak = {false, false, false, false};
        for (int i = 3; i >= 0; i--) {
            if (p >= (int) Math.pow(2, i)) {
                allowWeak[i] = true;
                p -= (int) Math.pow(2, i);
            }
        }
        return new SimplyDualWieldingConfig(
                empty,
                buf.method_10818(ItemCat.class),
                buf.method_10818(ItemCat.class),
                buf.method_10818(ConditionalBehavior.class),
                allowWeak,
                buf.method_10818(BalanceMode.class)
        );
    }

    private void write(class_2540 buf) {
        buf.method_52964(heldInstance.getEmpty());
        boolean[] allowWeak = heldInstance.getAllowWeakConfig();
        int p = 0;
        for (int i = 0; i < 4; i++)
            if (allowWeak[i])
                p += (int) Math.pow(2, i);
        buf.method_52997(p);
        buf.method_10817(heldInstance.getAttacks());
        buf.method_10817(heldInstance.getMines());
        buf.method_10817(heldInstance.getRestrictUse());
        buf.method_10817(heldInstance.getMode());
    }


    public SimplyDualWieldingConfig getHeldInstance() {
        return heldInstance;
    }

    @Override
    public @NotNull class_9154<? extends class_8710> method_56479() {
        return ID;
    }

}

==> SimplyDualWielding-7.0.1%2B1.20.1-Fabric-sources.jar: eva/dualwielding/network/ConfigPacket.java <==
package eva.dualwielding.network;

import eva.dualwielding.config.SimplyDualWieldingConfig;
import eva.dualwielding.config.enums.BalanceMode;
import eva.dualwielding.config.enums.ConditionalBehavior;
import eva.dualwielding.config.enums.ItemCat;
import net.fabricmc.fabric.api.networking.v1.FabricPacket;
import net.fabricmc.fabric.api.networking.v1.PacketType;
import net.minecraft.class_2540;
import net.minecraft.class_2960;
import java.util.function.Function;

public record ConfigPacket(SimplyDualWieldingConfig heldInstance) implements FabricPacket {

    public static final class_2960 CONFIG_PACKET_ID = class_2960.method_43902("eva", "config");
    public static final PacketType<ConfigPacket> TYPE = PacketType.create(CONFIG_PACKET_ID, new Function<class_2540, ConfigPacket>() {
        @Override
        public ConfigPacket apply(class_2540 buf) {
            return new ConfigPacket(buildFromBuf(buf));
        }
    });

    private static SimplyDualWieldingConfig buildFromBuf(class_2540 buf) {
        boolean empty = buf.readBoolean();
        int p = buf.readByte();
        boolean[] allowWeak = {false, false, false, false};
        for (int i = 3; i >= 0; i--) {
            if (p >= (int) Math.pow(2, i)) {
                allowWeak[i] = true;
                p -= (int) Math.pow(2, i);
            }
        }
        return new SimplyDualWieldingConfig(
                empty,
                buf.method_10818(ItemCat.class),
                buf.method_10818(ItemCat.class),
                buf.method_10818(ConditionalBehavior.class),
                allowWeak,
                buf.method_10818(BalanceMode.class)
        );
    }

    public void write(class_2540 buf) {
        buf.writeBoolean(heldInstance.getEmpty());
        boolean[] allowWeak = heldInstance.getAllowWeakConfig();
        int p = 0;
        for (int i = 0; i < 4; i++)
            if (allowWeak[i])
                p += (int) Math.pow(2, i);
        buf.writeByte(p);
        buf.method_10817(heldInstance.getAttacks());
        buf.method_10817(heldInstance.getMines());
        buf.method_10817(heldInstance.getRestrictUse());
        buf.method_10817(heldInstance.getMode());
    }

    @Override
    public PacketType<?> getType() {
        return TYPE;
    }

    public SimplyDualWieldingConfig getHeldInstance() {
        return heldInstance;
    }

}
